record

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 18, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WriteToRaw

func WriteToRaw(buffer []float64, fileName string) error

WriteToRaw creates the given file and dumps the buffer in 32 bit integer format.

func WriteToWav

func WriteToWav(sampleRate uint32, buffer []float64, fileName string) error

WriteToWav creates the given file and writes the buffer in WAV format.

Types

This section is empty.

Jump to